<template>
  <div>
    <div v-if="intro_video.top_text">
      <top_text :data="data" :five-sec-poster-show="show_overlay"
        :five-sec-poster-text="data['video-textoverlay-text']" :overlay-background="showOverlayBackground"/>
    </div>
    <div v-else-if="intro_video.mid_text">
      <mid_text :data="data" :five-sec-poster-show="show_overlay"
        :five-sec-poster-text="data['video-textoverlay-text']" :overlay-background="showOverlayBackground"/>
    </div>

    <div v-else-if="intro_video.bottom_text">
      <bottom_text :data="data" :five-sec-poster-show="show_overlay"
        :five-sec-poster-text="data['video-textoverlay-text']" :overlay-background="showOverlayBackground"/>
    </div>

    <div v-else-if="intro_video.animated_text">
      <animated_text :data="data" :five-sec-poster-show="show_overlay"
        :five-sec-poster-text="data['video-textoverlay-text']" :overlay-background="showOverlayBackground"/>
    </div>


    <!--video hotspots-->
    <div v-if="hotspotShow">
      <clickable_hotspot :data="currentHotspot" :hotspot-show="hotspotShow" :player="player"/>
    </div>

    <!--slider-->

    <Transition>
      <div v-if="showSlider && !hideSlider"
        class="fade-in position-absolute w-100 d-flex justify-content-center align-items-center flex-column-reverse"
        :style="$mq === 'mobile' ? 'top: 12%' : 'top: 5%'">

        <div
          id="barra" :style="`background-image: url('${data['slider-bar-img']}')`" class="align-self-center">
          <div id="thumb" :style="`background-image: url('${data['slider-thumb-drag-img']}')`"
            class="position-relative">
            <div id="des">5.0%</div>
          </div>
        </div>

        <div style="z-index: 999999999999999 !important;"
          :style="$mq === 'mobile' ? 'height: 4rem' : 'height: 5rem'" class="d-flex align-items-center">
          <custom-button
            :custom-style="{transform: 'rotate(180deg)'}"
            :data="data"
            :on-btn-click="sliderValSubmit"
            text="SUBMIT"
          />
        </div>
        <!--        <div id="btn_sub" :style="`background-image: url('${data['slider-submit-img']}')`"-->
        <!--          @click="sliderValSubmit()"></div>-->
      </div>
    </Transition>

  </div>
</template>

<script>

module.exports = {
  props: ['data', 'videoChange', 'intro_video', 'show_overlay', 'hotspotShow', 'currentHotspot', 'player', 'showSlider', 'pauseVideo', 'resumeVideo', 'sliderPauseVideo'],
  components: {
    'top_text': httpVueLoader('components/intro-video/top_text.vue'),
    'mid_text': httpVueLoader('components/intro-video/mid_text.vue'),
    'bottom_text': httpVueLoader('components/intro-video/bottom_text.vue'),
    'animated_text': httpVueLoader('components/intro-video/animated_text.vue'),

    'clickable_hotspot': httpVueLoader('components/intro-video/clickable_hotspot.vue'),
    'custom-button': httpVueLoader('components/buttons/button.vue')
  },
  computed: {
    showOverlayBackground() {
      const val = typeof this.data['video-textoverlay-highlight'] === 'string' ?
        (this.data['video-textoverlay-highlight']).toLowerCase() : this.data['video-textoverlay-highlight']
      let arr = ['yes', 'true', true]
      return arr.includes(val)
    }
  },
  watch: {
    showSlider() {
      if (this.showSlider === true && !this.hideSlider) {
        setTimeout(() => {
          this.initSlider()
        }, 200)
      }
    }
  },
  mounted() {

  },
  data() {
    return {
      hideSlider: false,
      sliderAudioEffect: new Audio(this.data['slider-audio']),
    }
  },
  methods: {
    initSlider() {
      // this.pauseVideo()
      this.sliderPauseVideo()
      this.sliderAudioEffect.play()
      this.sliderAudioEffect.currentTime = 0

      var aThumb = document.getElementById("thumb");
      const parentContainerWidth = $('#barra').width()
      Drag.init(aThumb, null, 10, (parseInt(parentContainerWidth) - 130), 0, 0);
    },

    startDrag(e){
      console.log('in startDrag ', e)
      const touch = e.targetTouches[0]
      Drag.start;
    },
    moveDrag(e){
      console.log('in moveDrag ', e)
      Drag.drag;
    },
    endDrag(e){
      console.log('in endDrag ', e)
      Drag.end;
    },

    sliderValSubmit() {
      this.sliderAudioEffect.pause()

      this.resumeVideo()
      this.hideSlider = true

      const sliderVal = $('#des').html()
      const dataForX93 = { xKey: 'X39', extra: sliderVal }
      this.$store.commit('fireAnalytics', dataForX93)
    }
  }
}
</script>

<style scoped>

.btn-primary {
  /*background-color: #565560;*/
  /*border-color: #565560;*/
}

.corner {
  position: absolute;
  top: 5%;
  /*this left 5% is also this template specific*/
  left: 5%;
  z-index: 1;
  /*added this bcz of card flip*/
  transform: rotate(180deg);
}

.btn-circle {
  width: 30px;
  height: 30px;
  text-align: center;
  padding: 6px 0;
  font-size: 12px;
  line-height: 1.428571429;
  border-radius: 15px;
}

button:focus {
  outline: none !important;
  /*background-color: #565560 !important;*/
}

button:active {
  /*background-color: #565560 !important;*/
}

button:hover {
  /*background-color: #565560 !important;*/
}


@media only screen and (max-width: 640px) {
  #barra {
    background: center 98px no-repeat scroll transparent;
    /* position: absolute; */
    background-size: contain;
    z-index: 20;
    /* width: 953px; */
    height: 140px;
    width: 95%;
    /*top: 25%;*/
    transform: rotate(180deg);
  }
}

@media only screen and (min-width: 640px) {
  #barra {
    background: center 85px no-repeat scroll transparent;
    /* position: absolute; */
    background-size: contain;
    z-index: 20;
    /* width: 953px; */
    height: 140px;
    width: 95%;
    /*top: 25%;*/
    transform: rotate(180deg);
    /* width: 899px; */
    /*height: 151px;*/
    /* top: 284px; */
    /*left: -146px;*/

  }
}

#thumb {

  background: no-repeat scroll center top transparent;
  cursor: move;
  height: 141px;
  position: relative;
  text-align: center;
  width: 120px;
}

@font-face {
  font-family: 'Montserrat-Bold';
  src: url('https://inf-shared-assets-s3.s3.amazonaws.com/fonts/Montserrat-Bold.ttf');
}

#des {
  color: #000000;
  font-family: Montserrat-Bold;
  letter-spacing: 0;
  font-size: 24px;
  font-weight: normal;
  height: 28px;
  margin-top: -10px;
  padding-top: 92px;
  width: 100%;
}

#btn_sub {
  background: repeat-x scroll left top transparent;
  cursor: pointer;
  height: 23px;
  /*position: absolute;*/
  width: 97px;
  z-index: 1000;
  transform: rotate(180deg);
  /*top: -34px;*/
  left: 4%;
  position: relative;
  top: 0;

}

#btn_sub:hover {
  background-position: 0 -24px;
}

.fade-in {
  animation: fadeIn linear 2s;
  -webkit-animation: fadeIn linear 2s;
  -moz-animation: fadeIn linear 2s;
  -o-animation: fadeIn linear 2s;
  -ms-animation: fadeIn linear 2s;
}

@keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}

@-moz-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}

@-webkit-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}

@-o-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}

@-ms-keyframes fadeIn {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}

.v-enter-active,
.v-leave-active {
  transition: opacity 0.5s ease;
}

.v-enter-from,
.v-leave-to {
  opacity: 0;
}


</style>
